SystemOrganization addCategory: #GODProcessorsTests!

TestCase subclass: #PCSEnglishPreprocessorTests
	instanceVariableNames: 'preprocessor aString aCleanStringAsBag'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODProcessorsTests'!

!PCSEnglishPreprocessorTests methodsFor: 'initialize-release' stamp: 'TD 11/20/2014 14:26'!
setUp
	preprocessor := PCSEnglishPreprocessor new.
	aString := 'Test Removing the Common Words of a String, and puctuation!!!!'.
	aCleanStringAsBag := #('test' 'removing' 'common' 'words' 'string' 'puctuation') asBag.! !

!PCSEnglishPreprocessorTests methodsFor: 'testPass' stamp: 'TD 11/20/2014 15:05'!
testRemoveStopWords
	"test tokenizer"
	self assert: (preprocessor preprocess: aString) = aCleanStringAsBag.! !

TestCase subclass: #PCSGODTaggerTests
	instanceVariableNames: 'aGODData aGODDataCollection pcsGODTagger'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODProcessorsTests'!

!PCSGODTaggerTests methodsFor: 'as yet unclassified' stamp: 'TD 11/16/2014 17:43'!
setUp
	|temGODData aStringCollection |
	pcsGODTagger := PCSGODTagger new.
	aGODDataCollection := Bag new.
	aGODData := GODData new.
	aGODData
		title: 'title1';
		content: 'Contedo de teste da Classe PCSTagger Contedo PCSTagger';
		width: 1.
	aStringCollection := Bag new.
	aStringCollection add: 'Teste Palavra'.
	aStringCollection add: 'Teste Palavra'.
	aStringCollection add: 'Teste Teste2 Ditongo'.
	aStringCollection add: 'Teste Portugus Palavra Teste2 Ditongo'.
	
	aStringCollection do: [ :str |
		temGODData := GODData new.
		temGODData content: str.
		aGODDataCollection add: temGODData.
	]
! !

!PCSGODTaggerTests methodsFor: 'testsPass' stamp: 'TD 11/16/2014 17:39'!
testAddTagsTo
	"test tokenizer"
	pcsGODTagger training: aGODDataCollection.
	pcsGODTagger addTagsTo: aGODData.
	
	self assert: (aGODData tags isEmpty) = false.
	! !

!PCSGODTaggerTests methodsFor: 'testsPass' stamp: 'TD 11/16/2014 17:48'!
testTagCollection
	"test TagCollection"
	pcsGODTagger training: aGODDataCollection.
	
	pcsGODTagger tagCollection: aGODDataCollection.
	
	aGODDataCollection do: [ :aGODData |
		self assert: (aGODData tags isEmpty) = false.
	]
	! !

!PCSGODTaggerTests methodsFor: 'testsPass' stamp: 'TD 11/16/2014 17:52'!
testTraining
	"test tokenizer"
	pcsGODTagger training: aGODDataCollection.
	self assert: (pcsGODTagger tagger dictIdf at: 'teste') = (4/(4+1)) log.
	self assert: (pcsGODTagger tagger dictIdf at: 'palavra') = (4/(3+1)) log.
	self assert: (pcsGODTagger tagger dictIdf at: 'ditongo') = (4/(2+1)) log.
	self assert: (pcsGODTagger tagger dictIdf at: 'portugus') = (4/(1+1)) log.! !

TestCase subclass: #PCSPortuguesePreprocessorTests
	instanceVariableNames: 'preprocessor aString aCleanStringAsBag'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODProcessorsTests'!

!PCSPortuguesePreprocessorTests methodsFor: 'initialize-release' stamp: 'TD 11/20/2014 16:05'!
setUp
	preprocessor := PCSPortuguesePreprocessor new.
	aString := 'Um Teste Simples'.
	aCleanStringAsBag := #('teste' 'simples') asBag.! !

!PCSPortuguesePreprocessorTests methodsFor: 'initialize-release' stamp: 'TD 11/20/2014 16:00'!
tearDown
	preprocessor := nil.
	aString := nil.
	aCleanStringAsBag := nil.! !

!PCSPortuguesePreprocessorTests methodsFor: 'testPass' stamp: 'TD 11/20/2014 16:09'!
testLatinCharacters
	|aBag|
	"simple test portuguese stopwords"
	aBag := Bag new.
	aBag add: 'cano'.
	aBag add: 'jos'.
	aString := 'cano Jos'.
	self assert: (preprocessor preprocess: aString) = aBag.! !

!PCSPortuguesePreprocessorTests methodsFor: 'testPass' stamp: 'TD 11/20/2014 16:05'!
testRemoveStopWords
	|aBag|
	"simple test portuguese stopwords"
	aBag := preprocessor preprocess: aString.
	self assert: aBag = aCleanStringAsBag.! !

TestCase subclass: #PCSPreprocessorTests
	instanceVariableNames: 'preprocessor aString aHTMLString aCleanHTMLString'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODProcessorsTests'!

!PCSPreprocessorTests methodsFor: 'as yet unclassified' stamp: 'TD 11/16/2014 13:39'!
setUp
	preprocessor := PCSPreprocessor new.
	aString := 'Ditongo Teste Portugus Palavra Teste Ditongo Ditongo Ditongo'.
	aHTMLString := '<HTML><head><title>Extrange Title<\title><\head><body>Teste<\body><\html>'.
	aCleanHTMLString := '   Extrange Title   Teste '.
	! !

!PCSPreprocessorTests methodsFor: 'testsPass' stamp: 'TD 11/20/2014 15:56'!
testPreprocess
	|bag|
	"test tokenizer"
	aString := 'test tokenizer'.
	bag := Bag new.
	bag add: 'test'.
	bag add: 'tokenizer'.
	self assert: (preprocessor preprocess: aString) = bag.! !

!PCSPreprocessorTests methodsFor: 'testsPass' stamp: 'TD 11/16/2014 11:00'!
testTokenizer
	|bag|
	bag := #('palavra' 'portugus' 'ditongo' 'ditongo' 'ditongo' 'ditongo' 'teste' 'teste') asBag.
	self assert: (preprocessor tokenizer: aString) = bag.! !

!PCSPreprocessorTests methodsFor: 'testsPass' stamp: 'TD 11/16/2014 17:27'!
testTreatFile
	"
	PCSPreprocessorTests run: #testTreatFile.
	"
	self assert: (preprocessor treatType: aString) = aString.
	preprocessor fileType: 'HTML'.
	self assert: (preprocessor treatType: aHTMLString) = aCleanHTMLString.
	
	
	! !

!PCSPreprocessorTests methodsFor: 'testsPass' stamp: 'TD 11/20/2014 16:18'!
testTreatPunctuation
	|bag|
	"test tokenizer"
	aString := 't!!e,,,st# t=okenizer?!!.,:;()[]{}%$#+='.
	bag := Bag new.	
	bag add: 'test'.
	bag add: 'tokenizer'.
	self assert: (preprocessor tokenizer: aString) = bag.! !

TestCase subclass: #PCSProcessorTests
	instanceVariableNames: 'pcsProcessor'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODProcessorsTests'!

!PCSProcessorTests methodsFor: 'initialize-release' stamp: 'FCB 11/10/2014 23:28'!
setUp
	pcsProcessor := PCSProcessor new.! !

!PCSProcessorTests methodsFor: 'counting' stamp: 'FCB 11/10/2014 23:34'!
testCountInOcurrencesOf
	"test mean given the key width"
	|aString aWord|
	aString := 'testE.;.;.; ,.;teste2,.; e teste'.
	aWord := 'teste'.
	self assert: (pcsProcessor countIn: aString ocurrencesOf: aWord) = 2.! !

TestCase subclass: #PCSStatisticsTests
	instanceVariableNames: 'pcsStatistics aCollection aGODCollection invalidCollection aGOD aGODData'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODProcessorsTests'!

!PCSStatisticsTests methodsFor: 'initialize-release' stamp: 'FKP 11/15/2014 18:44'!
setUp
	"Define local objects for tests"
	|godData|
	pcsStatistics := PCSStatisticsCalculator new.
	aCollection := #(1 3 3 4 4) asBag.
	invalidCollection := #(1 3  'a' 4 4) asBag.
	
	aGODData := GODData new.
	aGODData content:  'uva maa banana uva laranja uva banana banana uva maa uva'. 
	
	aGODCollection := Bag new.
	godData := GODData new.
	godData
		title: 'title1';
		width: 1.
	aGODCollection add: godData.
	godData := GODData new.
	godData
		title: 'title2';
		width: 2.
	aGODCollection add: godData.
	godData := GODData new.
	godData
		title: 'title3';
		width: 3.
	aGODCollection add: godData.
		
! !

!PCSStatisticsTests methodsFor: 'testsPass' stamp: 'TD 10/7/2014 19:02'!
testAverage
	"test average"
	self assert: (pcsStatistics average: aCollection) = 3.
	! !

!PCSStatisticsTests methodsFor: 'testsPass' stamp: 'TD 10/15/2014 10:47'!
testAverageKey
	"test average given the key width"
	self assert: (pcsStatistics average: aGODCollection key: [:x | x width]) = 2.
	
	! !

!PCSStatisticsTests methodsFor: 'testsPass' stamp: 'FKP 11/15/2014 19:37'!
testGenerateTags
	"test generateTags"

	| ac |
	pcsStatistics generateTags: aGODData.
	ac := aGODData tags.
	self assert: (((ac at: 1) = 'uva') & ((ac at: 2) = 'banana') & ((ac at: 3) = 'maa')). ! !

!PCSStatisticsTests methodsFor: 'testsPass' stamp: 'TD 10/14/2014 11:15'!
testMedian
	"test median"
	self assert: (pcsStatistics median: aCollection) = 3.
	! !

!PCSStatisticsTests methodsFor: 'testsPass' stamp: 'TD 10/15/2014 13:15'!
testMedianKey
	"test mean given the key width"
	self assert: (pcsStatistics median: aGODCollection key: [:x | x width]) = 2.! !

!PCSStatisticsTests methodsFor: 'testFail' stamp: 'TD 10/15/2014 10:39'!
testNaN
	self should: [pcsStatistics average: invalidCollection.] raise: Error! !

!PCSStatisticsTests methodsFor: 'testsPass' stamp: 'TD 10/20/2014 14:47'!
testStd
	"test standart deviation"
	self assert: (pcsStatistics std: aCollection) = (6/5) sqrt.! !

!PCSStatisticsTests methodsFor: 'testsPass' stamp: 'TD 10/14/2014 13:11'!
testStdKey
	"test mean given the key width"
	self assert: (pcsStatistics std: aGODCollection key: [:x | x width]) = (2/3) sqrt.! !

!PCSStatisticsTests methodsFor: 'testsPass' stamp: 'TD 10/20/2014 14:47'!
testVar
	"test standart deviation"
	self assert: (pcsStatistics var: aCollection) = (6/5).! !

!PCSStatisticsTests methodsFor: 'testsPass' stamp: 'TD 10/15/2014 13:17'!
testVarKey
	"test mean given the key width"
	self assert: (pcsStatistics var: aGODCollection key: [:x | x width]) = (2/3).! !

TestCase subclass: #PCSTaggerTests
	instanceVariableNames: 'pcsTagger aString aStringCollection'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODProcessorsTests'!

!PCSTaggerTests methodsFor: 'initialize-release' stamp: 'TD 11/16/2014 17:58'!
setUp
	pcsTagger := PCSTagger new.
	aStringCollection := Bag new.
	aStringCollection add: 'Teste Palavra'.
	aStringCollection add: 'Teste Palavra'.
	aStringCollection add: 'Teste Teste2 Ditongo'.
	aStringCollection add: 'Teste Portugus Palavra Teste2 Ditongo'.
	
	aString := 'Ditongo Teste Portugus Palavra Teste Ditongo Ditongo Ditongo'.! !

!PCSTaggerTests methodsFor: 'testsPass' stamp: 'TD 11/16/2014 10:58'!
testCreateDictTf
	"test method createDictTf"
	|dictTf aBag aCollection|
	dictTf := pcsTagger createDictTf: aString.
	self assert: (dictTf at: 'teste') = 2.
	self assert: (dictTf at: 'ditongo') = 4.
	
	aCollection := Bag new.
	aBag := pcsTagger preprocessor preprocess: aString.
	dictTf keysDo: [:key | 
	((dictTf at: key) / aBag size > pcsTagger maxTf |
	(dictTf at: key) / aBag size < pcsTagger minTf) ifTrue:
	[aCollection add: key]].
	self assert: (aCollection isEmpty) = true.

	self assert: (dictTf at: 'palavra') = 1.! !

!PCSTaggerTests methodsFor: 'testFail' stamp: 'TD 11/2/2014 11:17'!
testDictIdfMustNotBeEmpty
	
	self should: [pcsTagger getMoreRelevantsOf: aString.] raise: DictIdfMustNotBeEmpty! !

!PCSTaggerTests methodsFor: 'testsPass' stamp: 'FCB 11/10/2014 23:09'!
testGetMoreRelevantsOf
	"test tokenizer"
	|tags|
	pcsTagger createDictIdf: aStringCollection.
	"standard relevance := 0.8"
	tags := pcsTagger getMoreRelevantsOf: aString.
	
	self assert: (tags includes: 'ditongo') = true.
	
	"'Portugus'->0.7134773331462135"
	self assert: (tags includes: 'portugus') = false. 
	self assert: (tags includes: 'teste') = false.
	pcsTagger minRelevance: (0.7).
	tags := pcsTagger getMoreRelevantsOf: aString.
	self assert: (tags includes: 'portugus') = true. 
	self assert: (tags includes: 'teste') = false.! !

!PCSTaggerTests methodsFor: 'testsPass' stamp: 'FCB 11/10/2014 23:09'!
testGetMoreRelevantsOfSingleToken
	"test tokenizer"
	|tags|
	
	
	
	pcsTagger createDictIdf: aStringCollection.
	tags := pcsTagger getMoreRelevantsOf: 'Novidade Teste'.
	
	self assert: (tags includes: 'novidade') = true.! !

!PCSTaggerTests methodsFor: 'as yet unclassified' stamp: 'TD 11/2/2014 11:25'!
testNaN
	"Must be removed, wrong name"! !

!PCSTaggerTests methodsFor: 'testsPass' stamp: 'FCB 11/10/2014 23:07'!
testcreateDictIdf
	"test tokenizer"
	pcsTagger createDictIdf: aStringCollection.
	self assert: (pcsTagger dictIdf at: 'teste') = (4/(4+1)) log.
	self assert: (pcsTagger dictIdf at: 'palavra') = (4/(3+1)) log.
	self assert: (pcsTagger dictIdf at: 'ditongo') = (4/(2+1)) log.
	self assert: (pcsTagger dictIdf at: 'portugus') = (4/(1+1)) log.! !

!PCSTaggerTests methodsFor: 'testsPass' stamp: 'FCB 11/10/2014 23:10'!
testtfIdfWithFrequence
	"test 'tfIdf: WithFrequence:' method"
	pcsTagger createDictIdf: aStringCollection.
	
	self assert: (pcsTagger tfIdf: 'teste' withFrequence: 4) = ((4/(4+1)) log * 4).
	
	self assert: (pcsTagger tfIdf: 'ditongo' withFrequence: 2) = (((4 / 3) log) * 2).
	self assert: (pcsTagger tfIdf: 'portugus' withFrequence: 1) = ((4/2) log) .
	
	
	! !
